import * as echarts from 'echarts'
import {
  getXdataByBgColor,
  chartProcessDataCategory,
  chartProcessData
} from './func'
import lodash from 'lodash'
import { bindEvent } from './echartEvent'
function defaultConfig(
  container,
  data,
  height,
  name,
  prop,
  extraData = {},
  report,
  option = {}
) {
  height = height || chartHeight
  name = name || 'name'
  prop = prop || 'value'
  const el = document.getElementById(container)
  if (!el) {
    return new Promise((resolve, reject) => {
      reject('id不存在')
    })
  }
  let targetData = {}
  if (extraData.category) {
    targetData = chartProcessDataCategory(data, name, extraData.category, prop)
    targetData.hasCategory = true
  } else {
    targetData = chartProcessData(data, name, prop)
    targetData.hasCategory = false
  }
  return new Promise((resolve) => {
    resolve({
      container,
      data,
      height,
      name,
      prop,
      extraData,
      el,
      targetData,
      report
    })
  })
}

import {
  baseTable,
  categoryTable,
  getPieOption,
  baseLineChart,
  categoryLineChart
} from './table'
export async function eTableChart() {
  const res = await defaultConfig(...arguments)
  const { el, name, prop, data, targetData, extraData, report } = res

  const myChart = echarts.init(el)
  const option = targetData.hasCategory
    ? categoryTable(targetData, data, extraData, report)
    : baseTable(targetData, data, extraData, report)

  myChart.setOption(option)
  bindEvent({
    myChart,
    report,
    option,
    name,
    prop,
    category: extraData.category
  })
  return myChart
}

eTableChart.hasAnnotation = true

export async function ePieChart() {
  const res = await defaultConfig(...arguments)
  const { el, name, prop, data, targetData, extraData, report } = res

  const myChart = echarts.init(el)
  const option = targetData.hasCategory
    ? getPieOption(targetData, data, extraData)
    : getPieOption(targetData, data, extraData)

  myChart.setOption(option)
  bindEvent({
    myChart,
    report,
    option,
    name,
    prop,
    category: extraData.category
  })

  return myChart
}

export async function eLineChart() {
  const res = await defaultConfig(...arguments)
  const { el, data, targetData, extraData } = res

  const myChart = echarts.init(el)
  const option = targetData.hasCategory
    ? categoryLineChart(targetData, data, extraData)
    : baseLineChart(targetData, data, extraData)

  myChart.setOption(option)

  return myChart
}
