import * as echarts from 'echarts'
const showMarkLine = true
const fontTxtColor = '#000'
const barWidth = 12
const barBorderRadius = 8
import { formatterText, isOverLength } from '@/bigScreenCom/config.js'
const activeColor = '#24edf7'
const rotate = false

const dataZoom = [
  {
    type: 'slider',
    start: 0,
    end: 30
  },
  {
    type: 'inside'
  }
]
import lodash from 'lodash'

function checkActive(report, params) {
  if (!report.selectEl && report.selectEl !== 0) return false

  return params.dataIndex === report.selectEl
}

function processOption(option, extraData) {
  const chartOption = extraData.chartOption || {}
  return lodash.merge(option, chartOption)
}

export const baseTable = ({ xdata, ydata }, data, extraData, report) => {
  const option = {
    //  backgroundColor: '#00265f',
    tooltip: {
      trigger: 'axis',
      axisPointer: { type: 'shadow' }
    },
    grid: {
      left: '0%',
      top: '20px',
      right: showMarkLine ? '40px' : '20px',
      bottom: '4%',
      containLabel: true
    },
    xAxis: [
      {
        type: 'category',
        data: xdata,
        axisLine: {
          show: true,
          lineStyle: {
            color: fontTxtColor,
            width: 1,
            type: 'solid'
          }
        },
        axisTick: {
          show: false
        },
        axisLabel: {
          interval: 0,
          rotate: rotate ? -50 : 0,
          formatter: function (value) {
            return value
          },
          show: true,
          splitNumber: 15,
          textStyle: {
            color: fontTxtColor,
            fontSize: '12'
          },
          formatter: function (value) {
            return formatterText(value, extraData.isforMatX)
          }
        }
      }
    ],
    yAxis: [
      {
        type: 'value',
        axisLabel: {
          // formatter: '{value} %'
          show: true,
          textStyle: {
            color: fontTxtColor,
            fontSize: '12'
          }
        },
        axisTick: {
          show: false
        },
        axisLine: {
          show: true,
          lineStyle: {
            color: 'rgba(255,255,255,.1	)',
            width: 1,
            type: 'solid'
          }
        },
        splitLine: {
          lineStyle: {
            color: 'rgba(255,255,255,.1)'
          }
        }
      }
    ],
    series: [
      {
        // realtimeSort: true,
        type: 'bar',
        data: ydata,
        barWidth: barWidth, // 柱子宽度
        // barGap: 1, //柱子之间间距
        itemStyle: {
          normal: {
            color: function (params) {
              if (checkActive(report, params)) return activeColor
              if (params.data > 0) return '#2f89cf'
              else return 'rgba(156,107,155,0.5)'
            },
            opacity: 1,
            barBorderRadius: barBorderRadius,
            label: {
              color: '#fff',
              show: true,
              position: 'top'
            }
          }
        },
        markLine: showMarkLine
          ? {
              symbol: 'none',
              data: [
                {
                  type: 'average',
                  name: '平均值',
                  color: '#baf'
                }
              ],
              label: {
                color: 'yellow',
                distance: 0,
                position: 'end',
                formatter: (params) => {
                  return `${params.name} \n ${params.value}`
                }
              }
            }
          : {}
      }
    ]
  }

  return processOption(option, extraData)
}

export function categoryTable(
  { category, xdata, yObj, total },
  data,
  extraData
) {
  const showLabel = false
  const series = Object.keys(yObj).map((key) => {
    return {
      // realtimeSort: false,
      name: key,
      type: 'bar',
      data: yObj[key],
      barWidth,
      stack: false,
      barGap: 0,
      itemStyle: {
        normal: {
          barBorderRadius: barBorderRadius,
          opacity: 1,
          label: {
            show: !stack && !showLabel ? true : !!showLabel,
            position: 'top',
            color: '#fff'
          }
        }
      }
    }
  })
  let option = {
    tooltip: {
      trigger: 'axis',
      axisPointer: {
        type: 'shadow'
      }
    },
    color: ['#248ff7', '#64cd84', 'yellow', 'pink', 'green', 'red'],
    legend: {
      data: category,
      left: 'center',
      textStyle: { color: '#fff' },
      type: 'scroll'
    },
    grid: {
      left: '0%',
      top: '20px',
      right: '0%',
      bottom: '4%',
      containLabel: true
    },

    xAxis: [
      {
        type: 'category',
        // boundaryGap: false,
        data: xdata,
        // inverse: true,
        axisLine: {
          show: true,
          lineStyle: {
            color: fontTxtColor,
            width: 1,
            type: 'solid'
          }
        },

        axisTick: {
          show: false
        },
        axisLabel: {
          interval: 0,
          // rotate:50,
          show: true,
          splitNumber: 15,
          textStyle: {
            color: fontTxtColor,
            fontSize: '12'
          },
          formatter: function (value) {
            return formatterText(value, extraData.isforMatX)
          }
        },
        splitArea: {
          show: true,
          areaStyle: {
            // color: getXdataByBgColor(echartsIndex)
          }
        }
      }
    ],
    yAxis: [
      {
        splitNumber: 3,
        axisLabel: {
          formatter: '{value}',
          color: '#e2e9ff'
        },
        axisLine: {
          show: false
        },
        splitLine: {
          lineStyle: {
            color: 'rgba(255,255,255,0.12)',
            type: 'dotted'
          }
        },
        minInterval: 0
      }
    ],
    series
  }

  if (total) {
    series.push({
      name: '总和',
      type: 'bar',
      stack: '',
      z: -1,
      barGap: '-100%',
      legendHoverLink: false,
      itemStyle: {
        normal: {
          barBorderRadius: barBorderRadius,
          opacity: 1,
          color: 'transparent',
          label: {
            show: true,
            position: 'top',
            color: '#fff'
          }
        }
      },
      data: total
    })
  }
  return processOption(option, extraData)
}

function getLineSeries(name = '', data) {
  return {
    name,
    type: 'line',
    data: data,
    symbol: function (value, params) {
      // if (params.dataIndex + params.seriesName === curItem) return 'circle'
      return 'emptyCircle'
    },
    symbolSize: function (value, params) {
      // if (params.dataIndex + params.seriesName === curItem) return 20
      return 10
    },
    smooth: false,
    itemStyle: {
      opacity: 0,
      normal: { label: { show: true, color: '#fff' } }
    },
    emphasis: {
      label: {
        show: true,
        color: '#fff',
        fontSize: 20
      },
      itemStyle: {
        color: '#5d83ff',
        borderColor: '#fff',
        borderWidth: 2,
        opacity: 1
      }
    },
    areaStyle: {
      normal: {
        color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
          {
            offset: 0,
            color: '#5d83ff'
          },
          {
            offset: 1,
            color: 'rgba(0, 0, 0, 0)'
          }
        ])
      }
    }
  }
}

function getLineConfig(xdata, extraData) {
  return {
    tooltip: {
      trigger: 'axis',
      axisPointer: {
        lineStyle: {
          color: '#dddc6b'
        }
      }
    },

    grid: {
      left: '10',
      top: '30',
      right: '10',
      bottom: '10',
      containLabel: true
    },

    xAxis: [
      {
        type: 'category',
        boundaryGap: false,
        axisLabel: {
          interval: 0,
          formatter: function (value) {
            // return value
            return formatterText(value, extraData.isforMatX)
          },
          textStyle: {
            color: fontTxtColor,
            fontSize: 12
          }
        },
        axisLine: {
          lineStyle: {
            color: 'rgba(255,255,255,.2)'
          }
        },
        data: xdata
      },
      {
        axisPointer: { show: false },
        axisLine: { show: false },
        position: 'bottom',
        offset: 20
      }
    ],

    yAxis: [
      {
        type: 'value',
        axisTick: { show: false },
        axisLine: {
          lineStyle: {
            color: 'rgba(255,255,255,.1)'
          }
        },
        axisLabel: {
          textStyle: {
            color: fontTxtColor,
            fontSize: 12
          }
        },

        splitLine: {
          lineStyle: {
            color: 'rgba(255,255,255,.1)'
          }
        }
      }
    ]
  }
}
export function baseLineChart({ xdata, ydata }, data, extraData) {
  const option = getLineConfig(xdata, extraData)

  option.series = getLineSeries('', ydata)

  return processOption(option, extraData)
}

export function categoryLineChart({ category, xdata, yObj }, data, extraData) {
  const option = getLineConfig(xdata, extraData)
  category &&
    (option.legend = {
      top: '0%',
      data: category,
      textStyle: {
        color: 'rgba(255,255,255,.5)',
        fontSize: '12'
      },
      type: 'scroll'
    })

  if (yObj) {
    option.series = Object.keys(yObj).map((key) => {
      return getLineSeries(key, yObj[key])
    })
  }

  return processOption(option, extraData)
}

export function getPieOption({ xdata, ydata }, data, extraData) {
  const option = {
    tooltip: {
      trigger: 'item'
    },
    // title: {
    //   text: newData.title,
    //   textStyle: {
    //     color: 'white'
    //   }
    // },
    legend: {
      // show: !!this.show,
      top: 'bottom',
      right: '10%',
      left: '10%',
      bottom: 0,
      type: 'scroll'
    },
    series: [
      {
        // name: newData.name,
        type: 'pie',
        avoidLabelOverlap: false,
        radius: '70%',
        center: ['50%', '40%'],
        data,
        emphasis: {
          itemStyle: {
            shadowBlur: 15,
            shadowOffsetX: 0,
            shadowColor: 'rgba(0, 0, 0, 0.5)'
          }
        },
        label: {
          normal: {
            show: true,
            position: 'inside',
            formatter: '{c}', // 模板变量有 {a}、{b}、{c}、{d}，分别表示系列名，数据名，数据值，百分比。{d}数据会根据value值计算百分比

            textStyle: {
              align: 'center',
              baseline: 'middle',
              fontFamily: '微软雅黑',
              fontSize: 15,
              fontWeight: 'bolder'
            }
          }
        }
      }
    ],
    color: ['#00acee', '#52cdd5', '#79d9f1', '#a7e7ff', '#c8efff', '#49AAFC']
  }
  return processOption(option, extraData)
}
