export const ruleTrigger = {
  'm-input': 'onBlur'
}

export const getLabelWidth = (config) => {
  if (lodash.isNumber(config.labelWidth) && config.labelWidth >= 0)
    return config.labelWidth
  return null
}

import lodash from 'lodash'
import comData from '@/utils/comData/index'
import components from '@/utils/components'

export const mixinConfig = {
  components: { mLabelTip: components.mLabelTip },
  inject: {
    ...comData.comInject
  },
  props: {
    value: {
      type: [Array, String, Number],
      default: () => ''
    },
    isUsedFullForm: {
      type: Boolean,
      default: () => false
    },
    __config__: {
      type: Object,
      default: () => {
        return {}
      }
    },
    apiConfig: {
      type: Object,
      default: () => {
        return {
          status: false,
          url: '',
          method: 'get',
          params: {},
          config: {},
          otherData: {
            dataPosition: 'config.results'
          }
        }
      }
    },
    soureData: {
      type: Array,
      default: () => {
        return []
      }
    }
  },
  data() {
    return {
      apiLoading: false,
      requestRes: 'success',
      apiData: null,
      apiReturnConfig: null,
      apiSeverReqCur: null,
      eventListeners: [],
      oldFormData: {},
      curVal: ''
    }
  },
  computed: {
    getFormConfig() {
      return lodash.isFunction(this.formConfig)
        ? this.formConfig()
        : this.formConfig
    },
    comLabel() {
      return this.__config__.showLabel ? this.__config__.label : ''
    },
    attrInput() {
      const attr = lodash.cloneDeep(this.$attrs)
      if (!attr.maxlength) delete attr.maxlength

      const labelWidth = getLabelWidth(this.__config__)
      if (labelWidth !== null) {
        attr['label-width'] = labelWidth
      }
      if (this.__config__.required) {
        attr.required = true
        attr.rules = this.rules
      }
      return attr
    },
    rules() {
      if (!this.__config__.required) return []
      return [
        { required: true, message: `${this.__config__.label} 不能为空` }
      ].concat(
        this.__config__.regList.map((item) => {
          item.pattern && (item.pattern = eval(item.pattern))
          item.trigger = ruleTrigger[this.__config__.tag] || 'onChange'
          return item
        })
      )
    }
  },
  methods: {
    inputValue(val) {
      this.$emit('input', val)
    }
  },
  beforeDestroy() {
    this.eventListeners.forEach(({ event, listener }) => {
      this.$EventBus.$off(event, listener)
    })
    this.eventListeners = []
  }
}
