import { icons } from 'lakelib'
import lodash from 'lodash'
export const items = [
  'undo',
  'redo',
  '|',
  'heading',
  'paragraph',
  '|',
  'bold',
  'italic',
  'underline',
  'strikethrough',
  'superscript',
  'subscript',
  'code',
  '|',
  'list',
  'numberedList',
  'bulletedList',
  'checklist',
  '|',
  'align',
  'alignLeft',
  'alignCenter',
  'alignRight',
  'alignJustify',
  '|',
  'indent',
  'increaseIndent',
  'decreaseIndent',
  '|',
  'link',
  'codeBlock',
  'equation',
  // 'video',
  // 'twitter',
  'table',
  'hr',
  '|',
  // 'fontFamily',
  'fontSize',
  'fontColor',
  'highlight',
  'removeFormat',
  'formatPainter',
  'moreStyle'
]

export const langList = [
  'text',
  'c',
  'csharp',
  'cpp',
  'css',
  'go',
  'html',
  'java',
  'javascript',
  'json',
  'markdown',
  'php',
  'python',
  'rust',
  'sql',
  'typescript',
  'xml',
  'yaml'
]

function getFileObj(file, url) {
  return {
    name: file.name,
    size: file.size,
    type: file.type,
    lastModified: file.lastModified,
    url,
  }
}

export function getCustomImage(func, field = 'file') {

  return {
    name: 'customImage',
    type: 'button',
    icon: icons.get('image'),
    tooltip: (locale) => locale.toolbar.image(),
    onClick: (editor) => {
      const input = document.createElement('input')
      input.type = 'file'
      input.accept = 'image/*'
      input.onchange = async () => {
        const file = input.files[0]
        if (!file) return

        if (!func) {
          const reader = new FileReader()
          reader.onload = function (e) {
            const base64 = e.target.result
            editor.command.execute('image', {
              ...file,
              url: base64,
              status: 'done'
            })

          }
          reader.readAsDataURL(file)
          return
        }

        const form = new FormData()
        form.append(field, file)
        try {
          const url = await func({
            file, editor, form,
            process: (percent = 100) => {
              editor.command.execute('image', {
                ...getFileObj(file),
                status: 'uploading',
                percent,
              })
            }
          })
          editor.command.execute('image', {
            ...getFileObj(file, url),
            status: 'done',
            percent: 100,
          })
        } catch (error) {
          console.error(error)
          editor.command.execute('image', {
            ...getFileObj(file),
            status: 'error',

          })
        }

      }
      input.click()
    }
  }
}

export function getCustomFile(func, field = 'file') {
  if (!func || !lodash.isFunction(func)) return null
  return {
    name: 'customFile',
    type: 'button',
    icon: icons.get('file'),
    tooltip: (locale) => locale.toolbar.file(),
    onClick: (editor) => {
      const input = document.createElement('input')
      input.type = 'file'
      input.accept = '*/*'
      input.onchange = async () => {
        const file = input.files[0]
        const form = new FormData()
        form.append(field, file)
        try {
          const url = await func({
            file, editor, form,
            process: (percent = 100) => {
              editor.command.execute('file', {
                ...getFileObj(file),
                status: 'uploading',
                percent,
              })
            }
          })

          editor.command.execute('file', {
            ...getFileObj(file, url),
            status: 'done',
            percent: 100,
          })
        } catch (error) {
          console.error(error)
          editor.command.execute('file', {
            ...getFileObj(file),
            status: 'error',

          })
        }


      }
      input.click()
    }
  }
}
