import { icons, query, template } from 'lakelib'
export const props = {
  value: {
    type: String,
    default: ''
  },
  isRender: {
    type: Boolean,
    default: () => false
  },
  height: {
    type: [String, Number],
    default: '300px'
  },
  minHeight: {
    type: [String, Number],
    default: () => '300px'
  },
  placeholder: {
    type: String,
    default: () => '请输入内容...'
  },
  editorConfig: {
    typeof: Object,
    default: () => {
      return {}
    }
  },
  editorStyle: {
    typeof: Object,
    default: () => {
      return {}
    }
  },
  toolbarConfig: {
    type: Object || NULL,
    default: null
  },
  hiddlenToolBar: {
    type: Boolean,
    default: false
  },
  disabled: {
    type: Boolean,
    default: () => false
  },
  title: {
    type: String,
    default: ''
  },
  isUsedFullForm: {
    type: Boolean,
    default: () => false
  },
  __config__: {
    type: Object,
    default: () => {
      return {}
    }
  },
  baseDefaultConfig: {
    type: Object,
    default: () => {
      return {}
    }
  },
  baseConfig: {
    type: Object,
    default: () => {
      return {}
    }
  },
  editorDefaultEvent: {
    type: Object,
    default: () => {
      return {}
    }
  },
  editorEvent: {
    type: Object,
    default: () => {
      return {}
    }
  }
}

export function getFileBox(func) {
  return {
    type: 'inline',
    name: 'file',
    render: box => {
      const editor = box.getEditor();
      const value = box.value;
      if (editor.readonly && ['uploading', 'error'].indexOf(value.status) >= 0) {
        box.node.hide();
        return;
      }
      const boxContainer = box.getContainer();
      const rootNode = query('<div class="lake-file" />');
      rootNode.addClass(`lake-file-${value.status}`);
      appendContent(rootNode, box);
      boxContainer.empty();
      boxContainer.append(rootNode);
      if (!editor.readonly) {
        rootNode.on('click', () => {
          editor.selection.selectBox(box);
        });
        setFloatingToolbar(box, func);
      } else {
        rootNode.on('click', () => {
          func ? func(value) : window.open(value.url)

        });
      }
    }
  }
}

function setFloatingToolbar(box, func) {
  let items = [
    {
      name: 'download',
      type: 'button',
      icon: icons.get('download'),
      tooltip: locale => locale.file.download(),
      onClick: () => {
        func ? func(box.value) : window.open(box.value.url)

      },
    },
    {
      name: 'remove',
      type: 'button',
      icon: icons.get('remove'),
      tooltip: locale => locale.file.remove(),
      onClick: editor => {
        editor.selection.removeBox(box);
        editor.history.save();
      },
    },
  ];
  if (box.value.status !== 'done') {
    items = items.filter(item => item.name === 'remove');
  }
  box.setToolbar(items);
}

async function appendContent(rootNode, box) {
  const value = box.value;
  const infoNode = query(template`
    <div class="lake-file-info">
      <div class="lake-file-type"></div>
      <div class="lake-file-name">${value.name} (${fileSize(value.size)})</div>
    </div>
  `);
  const typeNode = infoNode.find('.lake-file-type');
  if (value.status === 'uploading') {
    const percent = Math.round(value.percent || 0);
    const progressNode = query(template`
      <div class="lake-progress">
        <div class="lake-percent">${percent} %</div>
      </div>
    `);
    const circleNotchIcon = icons.get('circleNotch');
    if (circleNotchIcon) {
      progressNode.prepend(circleNotchIcon);
    }
    typeNode.replaceWith(progressNode);
  } else {
    const fileIcon = value.status === 'error' ? icons.get('warningCircle') : icons.get('file');
    if (fileIcon) {
      typeNode.append(fileIcon);
    }
  }
  rootNode.append(infoNode);
}

function fileSize(size) {
  const units = ['KB', 'MB', 'GB'];
  let i = 0;
  size /= 1024;
  while (size > 1024 && i < 2) {
    size /= 1024;
    i++;
  }
  const sizeString = size > 0 ? Math.max(size, 0.1).toFixed(1) : 0;
  return `${sizeString} ${units[i]}`;
}