export const props = {
  tableHeight: {
    type: [Number, String],
    default: null
  },
  tableMaxHeight: {
    type: [Number, String],
    default: '300px'
  },
  tableSoureData: {
    type: Array,
    require: true
  },
  tableSourceLoading: {
    type: Boolean,
    require: true
  },
  tableColumn: {
    type: Array,
    require: true
  },
  selectedItemKeys: {
    type: Array,
    default: () => {
      return []
    }
  },

  paginationSource: {
    type: Object,
    default: () => { }
  },
  showTableSelect: {
    type: Boolean,
    default: () => {
      return true
    }
  },
  showTableConfig: {
    type: Boolean,
    default: () => {
      return true
    }
  },

  selectType: {
    type: [String, Number, Object, Array, Boolean],
    default: () => ''
  },

  apiConfig: {
    type: Object,
    default: () => {
      return {
        status: false,
        url: '',
        method: 'get',
        params: {},
        config: {},
        otherData: {
          dataPosition: 'data.results'
        }
      }
    }
  },
  apiSeverConfig: {
    type: Object,
    default: () => {
      return {}
    }
  },
  isCard: {
    type: [Boolean],
    default: () => false
  },
  cardConfig: {
    type: Object,
    default: () => {
      return {}
    }
  },
  tableConfigAttr: {
    type: Object,
    default: () => {
      return {}
    }
  },
  title: {
    type: String,
    default: () => ''
  },
  cardOtherConfig: {
    type: Object,
    default: () => {
      return {}
    }
  },
  isUsedFullForm: {
    type: Boolean,
    default: () => false
  },
  __config__: {
    type: Object,
    default: () => {
      return {}
    }
  },
  defaultConfigData: {
    type: Object,
    default: () => {
      return {}
    }
  },
  configData: {
    type: Object,
    default: () => {
      return {}
    }
  }
}

import { Message } from 'element-ui'
export function copyTableUiData(table, excludeLabels = []) {
  const mainHeader = table.querySelector(".el-table__header-wrapper table thead");
  const mainBody = table.querySelector(".el-table__body-wrapper table tbody");

  const headerCells = mainHeader.querySelectorAll("tr:first-child th");
  const bodyRows = mainBody.querySelectorAll("tr");

  const includedIndexes = [];
  const headerLabels = [];

  headerCells.forEach((th, index) => {
    const label = th.innerText.trim();
    if (!excludeLabels.includes(label)) {
      includedIndexes.push(index);
      headerLabels.push(label);
    }
  });

  const bodyTextRows = Array.from(bodyRows).map(tr => {
    const cells = Array.from(tr.querySelectorAll("td"));
    return includedIndexes.map(i => cells[i]?.innerText.trim() || "");
  });

  const headerRow = headerLabels.join("\t");
  const bodyText = bodyTextRows.map(row => row.join("\t")).join("\n");
  const finalText = `${headerRow}\n${bodyText}`;

  navigator.clipboard
    .writeText(finalText)
    .then(() => {
      Message({
        message: '已复制可见表格内容',
        type: 'success',
        duration: 2 * 1000
      })

    })
    .catch(() => {
      Message({
        message: '复制失败，可能不支持剪贴板',
        type: 'error',
        duration: 2 * 1000
      })

    })
}